summaryrefslogtreecommitdiffstats
path: root/kdat/Tape.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/Tape.h')
-rw-r--r--kdat/Tape.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/Tape.h b/kdat/Tape.h
index 335619c..153561e 100644
--- a/kdat/Tape.h
+++ b/kdat/Tape.h
@@ -34,7 +34,7 @@ class Tape {
int _mtime;
TQString _name;
int _size;
- TQPtrList<Archive> _children;
+ TQPtrList<Archive> _tqchildren;
FILE* _fptr;
@@ -148,7 +148,7 @@ public:
void removeChild( Archive* archive );
/**
* Recursively destroy all children of the tape index.
*/
void clear();
};
@@ -148,7 +148,7 @@ public:
void removeChild( Archive* archive );
/**
- * Recursively destroy all children of the tape index.
+ * Recursively destroy all tqchildren of the tape index.
*/
void clear();